@@ -24,7 +24,7 @@
 #' @source Garcia-Castellanos & Lombardo, 2007. Poles of inaccessibility: A
 #'   calculation algorithm for the remotest places on earth Scottish
 #'   Geographical Journal, Volume 123, 3, 227-233.
-#'   <https://dx.doi.org/10.1080/14702540801897809>
+#'   \doi{10.1080/14702540801897809}
 #' @source <https://github.com/mapbox/polylabel>
 #' @source <https://blog.mapbox.com/a-new-algorithm-for-finding-a-visual-center-of-a-polygon-7c77e6492fbc>
 #'
@@ -50,22 +50,23 @@
 #' \dontrun{
 #' # Find visual centers for North Carolina counties
 #' library(sf)
-#' nc <- st_read(system.file("shape/nc.shp", package="sf"))
-#' locations = do.call(rbind, poi(nc, precision=0.01))
+#' nc <- st_read(system.file("shape/nc.shp", package = "sf"))
+#' locations <- do.call(rbind, poi(nc, precision = 0.01))
 #' plot(st_geometry(nc))
 #' points(locations)
-
 #' }
 poi <- function(x, y = NULL, precision = 1.0) {
-  UseMethod('poi')
+  UseMethod("poi")
 }
 
 #' @export
 poi.default <- function(x, y = NULL, precision = 1.0) {
   xy <- grDevices::xy.coords(x, y)
 
-  stopifnot(is.numeric(precision),
-            length(precision) == 1)
+  stopifnot(
+    is.numeric(precision),
+    length(precision) == 1
+  )
 
   ends <- c(which(is.na(xy$x) | is.na(xy$y)), length(xy$x) + 1)
   n <- length(ends)
